# Copyright (c) 2020-present, The Johann Plugin Example Authors. All Rights Reserved.
# Use of this source code is governed by a BSD-3-clause license that can
# be found in the LICENSE file. See the AUTHORS file for names of contributors.

__version__ = "0.1.0-alpha"

import johann_plugin_example.tasks
from johann_plugin_example import config as example_config



# Copyright (c) 2020-present, The Johann Plugin Example Authors. All Rights Reserved.
# Use of this source code is governed by a BSD-3-clause license that can
# be found in the LICENSE file. See the AUTHORS file for names of contributors.

import time
from typing import TYPE_CHECKING, Dict, Union

import numpy as np  # now we're doing data science!

from johann.shared.config import JohannConfig, celery_app
from johann.shared.logger import JohannLogger
from johann.util import TaskState
from johann_plugin_example import config as example_config

if TYPE_CHECKING:
    from celery import Task


config = JohannConfig.get_config()
logger = JohannLogger(__name__).logger


@celery_app.task(bind=True)
def baby_nap(
    self: "Task", desired_duration: int, random_seed: int = example_config.RANDOM_SEED
) -> Dict[str, Union[float, str]]:
    logger.info(f"The baby will nap for up to {desired_duration} seconds")

    # set random seed
    np.random.seed(random_seed)

    # book-keeping
    start: float = time.time()
    stop: float = start + desired_duration
    now: float = start
    actual_duration: float = 0.0

    while now < stop:
        time.sleep(1)
        now = time.time()
        actual_duration = now - start

        # 10% chance that she will wake up
        if np.random.randint(1, 10) == 3:
            logger.info(f"The baby is up! She slept for {actual_duration} seconds!")
            break

        # report incremental progress
        self.update_state(
            state=TaskState.PROGRESS,
            meta={"current": actual_duration, "total": desired_duration},
        )

    # return final progress
    return {
        "current": actual_duration,
        "total": desired_duration,
        "status": "The baby is up!",
        "result": actual_duration,
    }



# Copyright (c) 2020-present, The Johann Plugin Example Authors. All Rights Reserved.
# Use of this source code is governed by a BSD-3-clause license that can
# be found in the LICENSE file. See the AUTHORS file for names of contributors.

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="johann_plugin_example",
    description="An example of a plugin for Johann",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Jeffrey James",
    author_email="lobotmcj@gmail.com",
    license="BSD",
    url="https://github.com/johannsdg/johann-plugin-example",
    include_package_data=True,
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: POSIX :: Linux",
    ],
    python_requires=">=3.6, <4",
    install_requires=["johann>=0.2.0a0", "numpy"],
)



# Copyright (c) 2020-present, The Johann Plugin Example Authors. All Rights Reserved.
# Use of this source code is governed by a BSD-3-clause license that can
# be found in the LICENSE file. See the AUTHORS file for names of contributors.
import os

from johann.shared.config import JohannConfig
from johann.shared.logger import JohannLogger

config = JohannConfig.get_config()
logger = JohannLogger(__name__).logger

# Modifications of main johann config, if any
config.HOST_IMAGE_PARAMS["johann_player_alpine"] = {
    "user": None,
    "env_pwd": None,
    "os": "LINUX",
    "python_path": "/usr/local/bin/python",
    "python_ver": "3.8",
    "pmtr_variant": "NONE",
    "control_method": "DOCKER",
    "pip_offline_install": False,
}

# Plugin-specific shared/config vars, if any
RANDOM_SEED: int = int(os.getenv("EXAMPLE_RANDOM_SEED", "42"))
